We offer three plot types: "default", "weights", and "combined". These plots are constructed post hoc to visualize different features of the fitted PLRD procedure.
The "default" option overlays the scatterplot of the original data with a pair of black curves showing representative regression functions in our data-driven function class. These curves are fitted for visualization and are not used to compute the PLRD estimate.
The "weights" option displays the fitted PLRD weights. It shows two sets of weights since we use two-fold cross-fitting.
The "combined" option displays both the default plot and the PLRD weights.
The dashed line marks the threshold, and the dotted lines indicate the window containing a specified percentage of the cumulative absolute PLRD weight mass on each side of the threshold.
Usage
# S3 method for class 'plrd'
plot(
x,
type = "default",
percentage.cumulative.weights = 0.99,
spline.df = 3,
annotate.tau = FALSE,
...
)Arguments
- x
A fitted
plrdobject returned byplrd().- type
The type of plot to display:
"default","weights", or"combined".- percentage.cumulative.weights
Percentage of cumulative absolute PLRD weight mass used to determine the displayed window on each side of the threshold. The default is 0.99, providing a visual approximation to the estimator's effective support.
- spline.df
Degrees of freedom of the natural spline used to plot a representative member of the data-driven function class, constrained to satisfy the smoothness condition of PLRD.
- annotate.tau
If
TRUE, marks the PLRD estimate with a curly brace in the plot.- ...
Additional graphical arguments to customize the plot, such as
xlim,ylim,xlab,ylabandmain.colmay contain up to three colors for the two sides of the threshold and the optional PLRD annotation.pchandcexmay be scalars or vectors of length two to customize the two sides of the threshold separately.